@@ -1,39 +1,41 @@
 from __future__ import annotations
 
 import json
+import os
+from os import PathLike
 from pathlib import Path
 from typing import Optional, Union
 
 import aiofiles
 import aiofiles.os
 
+JSONType = Union[list, dict, int, str, float, bool, None]
+
 
 class AsyncPath:
-    def __init__(self, fname: Union[str, Path]):
-        self._fname = fname
+    def __init__(self, *args, **kwargs):
+        self._path = Path(*args, **kwargs)
 
     async def mkdir(
         self, mode: int = 511, parents: bool = False, exist_ok: bool = False
     ) -> None:
         try:
-            await aiofiles.os.mkdir(self._fname, mode)
+            await aiofiles.os.mkdir(self._path, mode)
         except FileExistsError:
-            if exist_ok and not Path(self._fname).is_file():
+            if exist_ok and not self._path.is_file():
                 return
             raise
         except FileNotFoundError:
             if not parents:
                 raise
-            if isinstance(fpath := self._fname, str):
-                fpath = Path(fpath)
-            for p in list(fpath.parents)[::-1]:
+            for p in list(self._path.parents)[::-1]:
                 if not p.exists():
                     await aiofiles.os.mkdir(p, mode)
-            await aiofiles.os.mkdir(self._fname, mode)
+            await aiofiles.os.mkdir(self._path, mode)
 
     async def exists(self) -> bool:
         try:
-            return bool(await aiofiles.os.stat(self._fname))
+            return bool(await aiofiles.os.stat(self._path))
         except FileNotFoundError:
             return False
 
@@ -50,7 +52,7 @@ class AsyncPath:
 
     async def write_json(
         self,
-        context: Union[list, dict, int, str, float, bool, None],
+        context: JSONType,
         encoding: Optional[str] = None,
         errors: Optional[str] = None,
         **kw,
@@ -69,7 +71,7 @@ class AsyncPath:
         if mode is None:
             mode = "wb" if isinstance(ctx, bytes) else "w"
         async with aiofiles.open(
-            self._fname, mode, encoding=encoding, errors=errors
+            self._path, mode, encoding=encoding, errors=errors
         ) as fp:  # type:ignore
             await fp.write(ctx)
 
@@ -78,27 +80,58 @@ class AsyncPath:
         encoding: Optional[str] = None,
         errors: Optional[str] = None,
     ) -> str:
-        async with aiofiles.open(self._fname, encoding=encoding, errors=errors) as fp:
+        async with aiofiles.open(self._path, encoding=encoding, errors=errors) as fp:
             return await fp.read()
 
     async def read_bytes(self) -> bytes:
-        async with aiofiles.open(self._fname, mode="rb") as fp:
+        async with aiofiles.open(self._path, mode="rb") as fp:
             return await fp.read()
 
     async def read_json(
         self, encoding: Optional[str] = None, errors: Optional[str] = None, **kw
-    ) -> Union[dict, list, str, int, float, bool, None]:
+    ) -> JSONType:
         return json.loads(await self.read_text(encoding, errors), **kw)
 
     async def remove(self) -> None:
-        return await aiofiles.os.remove(self._fname)
+        return await aiofiles.os.remove(self._path)
 
     async def rmdir(self) -> None:
-        return await aiofiles.os.rmdir(self._fname)
+        return await aiofiles.os.rmdir(self._path)
 
     async def unlink(self) -> None:
-        return await aiofiles.os.remove(self._fname)
+        return await self.remove()
 
     async def rename(self, target: str) -> AsyncPath:
-        await aiofiles.os.rename(self._fname, target)
+        await aiofiles.os.rename(self._path, target)
         return self.__class__(target)
+
+    # Sync functions
+    def joinpath(self, *args: Union[str, PathLike]) -> AsyncPath:
+        return self.__class__(self._path.joinpath(*args))
+
+    @classmethod
+    def cwd(cls) -> AsyncPath:
+        """Return a new path pointing to the current working directory
+        (as returned by os.getcwd()).
+        """
+        return cls(os.getcwd())
+
+    @classmethod
+    def home(cls) -> AsyncPath:
+        """Return a new path pointing to the user's home directory (as
+        returned by os.path.expanduser('~')).
+        """
+        return cls(Path()._flavour.gethomedir(None))  # type:ignore
+
+    @property
+    def parent(self) -> AsyncPath:
+        return self.__class__(self._path.parent)
+
+    def __truediv__(self, key):
+        return self.__class__(self._path.__truediv__(key))
+
+    def __rtruediv__(self, key):
+        return self.__class__(self._path.__rtruediv__(key))
+
+    def __eq__(self, other):
+        return self._path == other._path
